# Changelog

<!--
   You should *NOT* be adding new change log entries to this file.
   You should create a file in the news directory instead.
   For helpful instructions, please see:
   https://github.com/plone/plone.releaser/blob/master/ADD-A-NEWS-ITEM.rst
-->

<!-- towncrier release notes start -->

## 1.1.0 (2025-10-02)


### New features:

- Make it work without requiring plone.app.multilingual @erral [#1](https://github.com/codesyntax/cs_flickrgallery/issues/1)

## 1.0.0 (2025-10-02)


### New features:

- Initial release @erral
